<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.Perception

Windows Runtime (WinRT) APIs for for the `Windows.Devices.Perception` namespace.

This package provides the `winrt.windows.devices.perception` module.
